==> apo-ws-client-6.00.50.1-sources.jar: fr/univlorraine/apowsclient/creationSE/CentreInsPedagogiDTO22.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.JAXBElement;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlElementRef;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CentreInsPedagogiDTO2 complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CentreInsPedagogiDTO2"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codCIP" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="TemIAAvantIP" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="TemInsElpOblAut" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CentreInsPedagogiDTO2", namespace = "VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codCIP",
    "temIAAvantIP",
    "temInsElpOblAut"
})
public class CentreInsPedagogiDTO22 {

    @XmlElement(required = true, nillable = true)
    protected String codCIP;
    @XmlElementRef(name = "TemIAAvantIP", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temIAAvantIP;
    @XmlElementRef(name = "TemInsElpOblAut", type = JAXBElement.class, required = false)
    protected JAXBElement<String> temInsElpOblAut;

    /**
     * Obtient la valeur de la propriété codCIP.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCIP() {
        return codCIP;
    }

    /**
     * Définit la valeur de la propriété codCIP.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCIP(String value) {
        this.codCIP = value;
    }

    /**
     * Obtient la valeur de la propriété temIAAvantIP.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemIAAvantIP() {
        return temIAAvantIP;
    }

    /**
     * Définit la valeur de la propriété temIAAvantIP.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemIAAvantIP(JAXBElement<String> value) {
        this.temIAAvantIP = value;
    }

    /**
     * Obtient la valeur de la propriété temInsElpOblAut.
     * 
     * @return
     *     possible object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public JAXBElement<String> getTemInsElpOblAut() {
        return temInsElpOblAut;
    }

    /**
     * Définit la valeur de la propriété temInsElpOblAut.
     * 
     * @param value
     *     allowed object is
     *     {@link JAXBElement }{@code <}{@link String }{@code >}
     *     
     */
    public void setTemInsElpOblAut(JAXBElement<String> value) {
        this.temInsElpOblAut = value;
    }

}

==> apo-ws-client-6.00.50.3-sources.jar: fr/univlorraine/apowsclient/creationSE/CentreInsPedagogiDTO22.java <==

package fr.univlorraine.apowsclient.creationSE;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Classe Java pour CentreInsPedagogiDTO2 complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType name="CentreInsPedagogiDTO2"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="codCIP" type="{http://www.w3.org/2001/XMLSchema}string"/&gt;
 *         &lt;element name="TemIAAvantIP" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *         &lt;element name="TemInsElpOblAut" type="{http://www.w3.org/2001/XMLSchema}string" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "CentreInsPedagogiDTO2", namespace = "VersionEtapeDTO.creerse.offreformation.dto.transverse.commun.apogee.education.gouv", propOrder = {
    "codCIP",
    "temIAAvantIP",
    "temInsElpOblAut"
})
public class CentreInsPedagogiDTO22 {

    @XmlElement(required = true, nillable = true)
    protected String codCIP;
    @XmlElement(name = "TemIAAvantIP", nillable = true)
    protected String temIAAvantIP;
    @XmlElement(name = "TemInsElpOblAut", nillable = true)
    protected String temInsElpOblAut;

    /**
     * Obtient la valeur de la propriété codCIP.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getCodCIP() {
        return codCIP;
    }

    /**
     * Définit la valeur de la propriété codCIP.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setCodCIP(String value) {
        this.codCIP = value;
    }

    /**
     * Obtient la valeur de la propriété temIAAvantIP.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemIAAvantIP() {
        return temIAAvantIP;
    }

    /**
     * Définit la valeur de la propriété temIAAvantIP.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemIAAvantIP(String value) {
        this.temIAAvantIP = value;
    }

    /**
     * Obtient la valeur de la propriété temInsElpOblAut.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getTemInsElpOblAut() {
        return temInsElpOblAut;
    }

    /**
     * Définit la valeur de la propriété temInsElpOblAut.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setTemInsElpOblAut(String value) {
        this.temInsElpOblAut = value;
    }

}
